#!/usr/bin/env python

'''test_open_file.py - tests the open_file module
Chris R. Coughlin (TRI/Austin, Inc.)
'''

import unittest
import os
import os.path
from podbrowser.util import open_file

class TestOpenFile(unittest.TestCase):
    '''Tests the open_file function'''

    def setUp(self):
        self.fname = os.path.join(os.path.dirname(__file__), '_empty_file_')

    def test_filenotfound(self):
        '''Verify IOError raised if file not found'''
        with self.assertRaises(IOError):
            open_file.open_file('NO_SUCH_FILE')

    def test_windows_noprogram(self):
        '''Verify WindowsError raised if no associated application found (Windows only)'''
        if os.name == 'nt':
            with self.assertRaises(WindowsError):
                open_file.open_file(self.fname)