#!/usr/bin/env python

'''about_dlg.py - simple wxPython About Dialog
Chris R. Coughlin (TRI/Austin, Inc.)
'''

import wx
from wx.lib.embeddedimage import PyEmbeddedImage

class AboutDialog(wx.Frame):
    '''Displays a simple About dialog.'''

    def __init__(self, parent, id, version):      
        wx.Frame.__init__(self, parent, id, "About PODBrowser",
            style=wx.DEFAULT_FRAME_STYLE & ~(wx.RESIZE_BORDER | 
            wx.RESIZE_BOX | wx.MAXIMIZE_BOX | wx.MINIMIZE_BOX))
        self.version = version
        self.SetIcon(parent.GetIcon())
        vbox = wx.BoxSizer(wx.HORIZONTAL)    
        self.logopanel = wx.Panel(self)
        self.img = wx.StaticBitmap(self.logopanel, wx.ID_ANY, self.getlogo())
        self.logopanel.Refresh()
        vbox.Add(self.logopanel)
        self.SetSizerAndFit(vbox)       
        self.CentreOnScreen()
        self.Show()

    def getlogo(self):
        '''Returns a wx.Bitmap from the embedded logo data'''
        logo = PyEmbeddedImage(
                "iVBORw0KGgoAAAANSUhEUgAAAeAAAAECCAYAAAAmWAQcAAAABHNCSVQICAgIfAhkiAAAAAlw"
                "SFlzAAAGsQAABrEBoXAABQAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
                "ACAASURBVHic7J13WJPX28e/SUgIIey9l+IG3AMH7j1at1atq9Zth3XVulrr/tVV22q1S0Xq"
                "qHuLe09cyEYR2TMQICHP+0dKXhSS5wQywJ7PdXFdmpznnJP1fM+5zz04AycvY0ChUCgUCsWg"
                "mADAno3zYGLCM/ZcKBQKhUJ575HLSzFq9mqlAJuY8CDgmxh7ThQKhUKh/GfgGnsCFAqFQqH8"
                "F6ECTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSK"
                "EaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSK"
                "EaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKEaACTKFQKBSKETAx9gQoFMr7"
                "wa1bt1BYWAhvb2/4+PigoKAAe/fuRUlJCXr27Ak/Pz9kZGTg6NGjEIlE6NGjB2xsbJCRkYHX"
                "r19DJBKhTp064HA4UCgU4HLp/oDyfkO/4RQKRSNxcXE4efIkjhw5onps9OjRcHNzw7Rp01SP"
                "9evXD126dMFff/0FAJBIJJg8eTKmT5+Oe/fuAQBiYmIwYcIEjBgxAomJiQCAAwcOICgoCP7+"
                "/igqKgIAzJ07FzweD4GBgar+p0+fjhYtWmDevHmqx2bPno1PP/0Uhw4dAgAwDIN9+/bh9OnT"
                "SE1NBQAoFArI5XJ9vDUUSrWgAkyhUN4iMjISf/75p+r/CxYsQJ8+ffD555+rHsvOzkZycrJK"
                "RAHA1NQUAFBSUgIAEIlEqufKBLCwsFD1WNnzUqkUAMDhcCAUClXtFApFhXndu3cPcXFxqsf2"
                "7NmDn3/+GXfu3AEA5OfnY8SIEejVqxfOnj0LQLkz5/P5sLCwwOPHjwEAp06dQs+ePTF8+HDV"
                "fC9duoRffvkFx48fV/WfmpqKjIwMKuAUvUBN0BTKf5y8vDyIxWJwuVz89ttvGD9+PACgW7du"
                "cHFxQefOnREWFobXr1+DYRhwOBwMGzYMgYGBaNasmaqfkydPgsfjwdnZGQBgYWGBgoICmJmZ"
                "gcPhAABCQkKQk5ODwsJCODo6AgCGDh2KwMBAFBUVqdqNGjUKjRs3hrW1tar/fv36wcfHB82b"
                "N1c9FhgYiPT0dHh7ewNQLgzKsLGxAQDk5OQAUO7IywQ+OjoaZ86cAY/HQ2hoKABg7969+Pnn"
                "n9GkSRP07dsXADBmzBicPXsWgwYNUu2yu3btivz8fEyZMgUTJ06ERCLB559/DpFIhIkTJ6JJ"
                "kyZITU3FyZMnIRKJ0KtXL1haWiIrKwsZGRkQiURwd3ev9udGeQ8YOHkZU1wiYygUyn+LnJwc"
                "ZubMmYyFhQVz5MgRhmEYJjo6mgHAcDgc1WM5OTlMVFQUI5VKjTldIhQKBZOZmcnExMQwEomE"
                "YRiGSUxMZH755Rdm9erVTF5eHsMwDHPgwAGmZ8+eTLdu3VTXjh07lgHAdOzYUfVYixYtGADM"
                "xx9/rHpMLBYzAJhVq1ap+gfAAFC9Z2fPnlU9FhUVxTAMw2zcuJEBwPD5fFVfs2fPZmxtbZmu"
                "Xbu+9Vi/fv2Y9evXqx5buXIls3LlSubGjRsMwzBMSUkJc/z4cebChQtMVlYWwzAMk5eXx0RE"
                "RDBPnz5liouLGYZhmIKCAiY9PV3VhlIzKC6RMQMnL2OoAFMo/yEUCgUTHx/PMIzyJu7i4sIA"
                "YHr06KFqc+jQISYtLc1IMzQuMplMJdIMwzBXr15l9u3bx1y/fp1hGOX7N3XqVOajjz5iTpw4"
                "wTAMw8TFxTEBAQGMj48Pc/nyZYZhGObgwYMqAX7z5g3DMAzz/fffMwAYKysrVf8fffQRA4Bp"
                "2bKl6rHmzZszAJhx48apHhOJRAwAZvXq1QzDMMzr169V/R87doxhGIY5fvy46rGYmBiGYRhm"
                "w4YNDADGzMxM1dfkyZMZHo/HtGrVSvVYnz59GHd3d2bWrFmMQqFgiouLGX9/f8bDw4NZvXo1"
                "8+rVK+b69euMq6sr4+rqyvzyyy/MzZs3mY0bNzI2NjaMjY0Ns3PnTmb//v3Mxx9/zIjFYsbK"
                "yorZtm0bs2rVKiYwMJARCASMh4cHs2jRIiYxMbH6H1YtpkyAOQMnL2PCti6EgE+t0RTK+8yh"
                "Q4cwb948yGQyxMTEgMfjYe3atXj69Clmz56Npk2bGnuK7xUFBQXIz8+Ho6MjuFwuXr16hcjI"
                "SMhkMvTp0wcAcOTIETx48ACOjo6YOnUqAGDOnDl4+vQpOnTogDFjxiAvLw9du3ZFQUEBPvro"
                "I3To0AGxsbFYvnw5AGDw4MGws7NDXFwczp07BwDo2bMnTExMEB0djaioKPB4PDRr1gwymQzx"
                "8fHIzc2FQCCAvb09pFIpcnNzVZ7n756964OrV68iODhY7+PUVEpkcgybvhJUgCmU/wg7duzA"
                "5MmTAQD//PMPBg4caOQZvR9IpVJIJBLk5+dDIpFU+NP2cYlEgtLSUmO/LL0gFAphbm6OY8eO"
                "oU2bNsaejtEoE2CquhTKe8yhQ4cgk8kwbNgwTJo0Cffv30dISIjKyYjyNgqFAhkZGUhLS6v0"
                "LzU1VfXvjIwMSCQSg+wY1WFqagpHR0eYm5sjKioKCoUCnp6e8Pb2hkKhwNWrVwEA7dq1g5eX"
                "FzIzM3HmzBkASgczZ2dnRERE4PTp0+ByuVi1ahUEAgHOnDmDx48fw9PTE9OnTwefz0dYWBjS"
                "0tIQFBSEDz/8EAKBAL///ju4XC6Cg4PRpk0byOVynDhxAmKxGB07doSXlxcKCwvx4sULiEQi"
                "1K9fHwKBwGjvV02D7oAplPeUxYsX49tvv4WVlRWePHnyn/e8LSkpwcuXL5GQkPDW35s3b1Ti"
                "mpmZqRdBFYlEEIvFb/2Zm5urTL7e3t6wsbHB69evcfv2bRQWFmLt2rUQi8X4+eefcfz4cfj5"
                "+SE8PBxisRjDhw+v4J3t4eGBpKQkzJ8/H99//z0kEgk6deoEe3t7zJ8/H507d0ZycjJCQ0Nh"
                "b2+P/v37w8bGBvn5+ZBKpbCzswOPx9P5a6dUhO6AKZT3nEGDBmHVqlWws7NDenr6ey/Acrm8"
                "gri+K7RVEVcTExPY29vD0dERTk5OcHR0hKOjIxwcHGBhYVFBWMvEtfy/ZTIZwsLC8OjRIwwf"
                "PhwtW7bErVu3VGbY69evo23bttizZw92794NQHmOa2tri4cPH+L48ePIy8uDh4cHAGUilA4d"
                "OqBly5aqeV6+fBlisRi2trYAALFYrEqAUoarq+tb8dyAMlzMwsJC6/eFUn2oAFMo7xHXrl1D"
                "ZGQkJk6ciObNm+Off/5BSEgIzM3NjT01nZKSkoKIiIi3/p4/f65KqkGCg4MDvL294ebmphLV"
                "8gJb9n9bW1tVfDIpP/30E65evYoWLVpgzpw54HK5mDhxImQyGezt7dGyZUt4enqq2r98+RJt"
                "27ZFo0aN0K9fP3h5eakWC1OnTsWkSZNU8dUAMG7cuApj+vj4aDVHivGhAkyhvCeEh4ejX79+"
                "kEql4HA4mDBhQq0/65VKpXj27JlKZB8/foyIiAikp6drvI7D4cDJyQleXl7w9vaGt7d3hX+X"
                "z9SlLYWFharrf/vtN+zcuRN8Ph/nz58HoHRyO336NNLT0zFnzhzw+XzUq1cPGRkZqj6cnZ1x"
                "4sQJeHp6ws/PD4AyscjRo0ffGsve3r7K86TUbKgAUyjvCd7e3rC1tUVWVpbKVFnbKC4uxo0b"
                "NxAeHo7w8HDcunVL467W1NQUDRs2REBAAAIDA9GwYUOVwJZlvdIlV65cwbx583D37l28fv0a"
                "Dg4OSEtLw5UrV2Bqagq5XA4TExO0bNkS6enpaNy4seramzdvvmWJ4HA46N27t87nSKk9UAGm"
                "UGo5jx49QmBgIHx8fHD+/HmkpqaiQ4cOxp4WESUlJbh9+7ZKcG/cuKEqyPAubm5uCAwMREBA"
                "gOqvXr16MDHRz22ssLAQq1atQnh4OBYtWoRevXpBKBTixo0bAJTve7du3dCmTRv07t0bQUFB"
                "KCoqglgsxooVK7BixYq3+nvfjgEo1YcKMIVSizl8+DCGDh2K2bNnY+3atfD394e/v7+xp6WR"
                "9PR0hIWF4fDhw7h27dpbBRrKEAqFaNu2LUJCQtChQwcEBgaqnIv0xZUrV3D27Fk4Oztj2rRp"
                "EAqF2LJlC7Kzs3H27Fn06tULzZo1wwcffIC2bduifv36AICOHTuiY8eOep0b5f2ECjCFUktR"
                "KBRYvHgxZDIZdu3ahc8//xwuLi7Gnlal5OXl4dChQ9i7dy/Onz9fobqQqakp2rRpg5CQEHTu"
                "3Blt2rRRVVfSF1FRUTh37pyqpOKmTZuwf/9+BAQEYNq0aeByuejVqxfS09MREBAAAODxeDh4"
                "8KBe50X570AFmEKppXC5XFy8eBGTJk3CggULapz4FhUV4cSJE9izZw+OHz9ewbTcqlUr9OrV"
                "CyEhIWjbtq1ezmzV8euvv2LSpEngcDgYOnQoHBwc0LlzZ5w8eRJOTk6qs9w9e/YYbE6U/x5U"
                "gCmUWkhoaCiGDBkCW1vbGrcje/HiBdatW4ewsDDk5eW99VyDBg0watQojBw5UuX5q2+Ki4vx"
                "448/IjQ0FN988w369u2Lrl27AlA6Ql27dg2DBg3ChAkT8Mknn+jtTJlCeReusSdAoVC0Y8eO"
                "HRg5ciQ6deqElJQUY09HxcOHDzFs2DA0bNgQO3bsUImvh4cH5s6diwcPHuDZs2f4+uuv9S6+"
                "aWlpKmcpPp+PtWvX4vbt26rav97e3ggLC0NycjIGDRoEQHnuTMWXYkjot41CqWX8888/AICs"
                "rCyIxWIjz0aZxWnlypU4fvy46jGhUIgxY8ZgzJgxaN++vdaJLKrDt99+i6VLl8Ld3R0JCQng"
                "crkYPnw47t69iy5duqjaDR061GBzolAqgwowhVLLOHz4MJYvX47hw4cbVYDPnTuH7777Dhcv"
                "XlQ9ZmlpiWnTpmHOnDlwcnIyyDzy8vKwfft2TJo0CVZWVmjQoAFKS0uRmJiIBw8eoGnTptiw"
                "YYNBFwEUCglUgCmUWsJff/2F3r17w87ODsuWLTPaPGJjYzFlyhRV1idAmdZxzpw5mD59Oqys"
                "rAw2l/T0dNStW1dVz3bu3Lno06cPli5dimHDhqFBgwYAQMWXUiOhZ8AUSi3gzp07GDt2LOrV"
                "q4crV64YZQ5yuRxr1qxBkyZNVOLr6emJTZs2ITExEQsXLjSI+D569Ai7du0CoBT+Vq1aAYCq"
                "8ICZmRmWLFmiEl8KpaZCBZhCqQWU1XAFgIYNGxp8/Hv37qFVq1aYN28epFIpzMzMsGbNGsTG"
                "xmLmzJkwMzMzyDw2bdqEoKAgTJ06FampqQCAVatW4caNGyoHKwqltkAFmEKpBSxatAhXr17F"
                "jh07YGdnZ7BxCwsL8eWXX6J169Z48OABAKBr1654/Pgx5s6daxCv4fDwcCQlJQEA+vbtCy6X"
                "C1NTU9V8mjVrpirrR6HUJugZMIVSg8nIyEBaWhoaNmyIdu3aGXTsiIgIfPDBB4iLiwMA2NjY"
                "YP369Rg/frxBxmcYBqNGjUJoaCiGDx+O0NBQ+Pn54cCBA+jSpQssLS0NMg8KRV/QHTCFUoP5"
                "6quvEBQUhPnz5xt03KNHjyI4OFglvkOHDsXz588NIr5laSo5HI6qBu6VK1eQlZUFABg0aBAV"
                "X8p7ARVgCqWGsnv3buzevRsymQyZmZkGG3fdunUYNGgQJBIJzMzMsGfPHoSFhRkkrOjAgQPw"
                "9/dXOZotW7YMCxcuxPPnz/VejIFCMTScgZOXMWFbF0LAp9ZoCqUmERgYiIiICDg6OuLp06d6"
                "L8wuk8nw6aefYufOnQAAFxcXHD58GC1bttTruGXk5+fD19cXGRkZCAoKwr1798Dl0j0C5f2j"
                "RCbHsOkr6Q6YQqmpHD58GKNGjcLGjRv1Lr6ZmZno1q2bSnybNm2K27dv6118ZTIZtmzZAoZh"
                "YGFhge+++w6+vr5YsmQJFV/Kew/d9lIoNQyGYcDhcODt7Y3du3frfbykpCSEhIQgNjYWAPDh"
                "hx/izz//hEgk0uu4ycnJ+OCDD3D79m2YmZlh4sSJmDRpEsaNG6f3UoQUSk2ALjEplBrGypUr"
                "MXDgQDx9+lTvY2VkZKB79+4q8V2wYAH279+vd/EFAGtraxQWFgIALl++DACqECMK5b8A3QFT"
                "KDWIrKwsrF27Frm5uSgoKMC5c+f0NlZeXh569eqFyMhIAMDq1avx1Vdf6W08QGlyXr9+PWbP"
                "ng2RSIQDBw7gxIkTmDNnjl7HpVBqIlSAjQRTWorcqHjkx79CYXIqpKkZkEuLUFpUDA6XC4G1"
                "JUytLSGwsoTAxhLW9f1g4etp7GlT9IypqSlmz56NDRs24Pvvv9fbOEVFRRgwYIAqfeOCBQv0"
                "Lr4SiQTdu3fHzZs3ERMTgx07dsDf3x/+/v56HZdCqanUCAF+snEnon/bX/2OOBzwTAXgW4oh"
                "sBBDYGUBsY8H7AIbwi6oAcw9XKs/RlVhGGQ/i8abizeRevUOsp5EoVRapFUXQkc7OLYKgkPr"
                "ILh1DYbQUX8ZkU72HIOiNO1DXzhcLkxEZuBbmINvKQbfQgyBpRgWPh6wDWwA2yb1IbA2XAzn"
                "w++2In7/cfaGhHB4PJiYCcETCcEXmYFvIYbY2x2Wfl6w9POCbUB98C2rXqHI3Nwcy5Ytwxdf"
                "fKG3WFe5XI4hQ4bg0qVLAICpU6di5cqVehmrPGKxGN7e3rh58yZSU1NRUlICgUCg93EplJpK"
                "jRDgrAfPIMsv0ElfMgBF6Vn//8ClW4j+959mTvbwHtwbvsP6wtzdRSfjsVGSm4+EAycRs+cw"
                "JAlJ1eqrKC0TL4+dx8tj5/Fg+SZ4DuiGehOHw8rfR0ezVVKcmY382JdVvr4kNx94o/55sacr"
                "7FsGwmdIHzi0DKjyOCRk3n+is+9WGSU5eW/9P/X6PdW/OTweHFoGwLVrMLwG9YCpDXlxglWr"
                "VqFFixbo1q2b3sRXoVBg3Lhxqtq9o0aNwpYtW/QyVhkrVqzA6NGj4evri+3bt6NLly6YNGkS"
                "rVBE+c9TI+KAD7ccgOLsXMMNyOHAtUs7NFs6ByIXR70MIcuT4MWv+xD1237ICwr1MkYZLiFt"
                "0Hz55xC56iZRQsrl27g8Ya5O+mLDqq4PfEcOgPcHPcG3MNdp30ypAgcDe6G0qFin/ZJiYi5C"
                "vYnDUW/ScJiINBcriIyMROPGjVFaWoqNGzdi1qxZepnTihUr8M033wAA+vfvj4MHD+o1n/Os"
                "WbOwefNmtGjRAteuXaM7XgoFNSgOWJqSbljxBQCGQfL5azjd+2PE7Tum8+4TDp7Cia6j8Gzr"
                "H3oXXwB4c/EmzvSfiOTz13TSX/azKJ30Q0JudDweLN+IE11GIunURZ32nRebaDTxBQB5QSGe"
                "btqF030nsFoUkpKS4OLiAnNzcwwfPlwv8zl//jyWLl0KAAgODkZYWJjeiymUFY7gcDiQSqV6"
                "HYtCqW0YXYCznxruZv8uMkkB7i5ai4i1P+ukv5KcPFwePxe3v/re4IuKktx8XJ2yEA9XbgUY"
                "plp9ZT+JZm+kY4qzc3F9xhLc/HyF0oStA3KeGf51VEbBq2ScGzoVmQ+fqW3TrVs3REdH4/Tp"
                "03pJ+ZicnIxRo0ZBoVDA0dERYWFhEAqFOh8HUHo6R0cr3/slS5bgxx9/xLlz5wxSK5hCqU3U"
                "AAE2/k0y8uc9eLJxZ7X6yH0RhzMDJiHlym0dzapqRO0Mq/aCwpiLopdHzuF03/GQvEyudl/G"
                "fB3vIsuT4Oac5ZAXVtwFHjx4EKWlpRAKhQgODtb52HK5HCNGjEBaWhq4XC727NkDV1f9OCQW"
                "FhZiwIABCA4OVoU3TZ06lRZPoFAqoQYIcM24ST7b/DtSr91jb1gJudHxuDjmMxQmp+p4VlUj"
                "8pe9iN17pErXyvIkKHhVffGrDtKUdFwa98XbznRVIPtJzfhulVGQ9AZPfnh7oXf48GEMHjwY"
                "TZo0QUxMjF7GXbRo0VvFDbp27aqXcQDg2rVrOHv2LNLT07Fx40a9jUOhvA8Y3QuaVIDF3u7g"
                "sOSGleVLUJSRXWUT7IMVm9Dz+E5weDzia/JjX+LSmM9QnJWj9XhcAR/2zZvAtkk9mNpaw9TW"
                "GgJrS8gLpSjJyUN+QhLSrt9DblS81n3fX/o/WNbxgkPLQK2uy35OJgJ8C3O1nuSy/AKU5ORB"
                "Jqm693HBq2RcnjAXnfdsqppzFsMgh+C1cHhcNJw+lqhLhbwUstx8lOTmozgnF1mPnmvtYZ1w"
                "4CQCvvwEXAEfALB3714AgFQqhaen7uO8jx49irVr1wIAevXqhUWLFul8jPJ0794du3btwrlz"
                "5/TuXU2h1HaMKsDF2bmQpqSztjMxF6HP2b8AgrAFRYkMhW/SkPM8GpHbQ5H16DnxfPJiEpBw"
                "8BR8hvYlai9JSEL4mDlK0SeFw4F7jw7wHTkADi0CwBOyp90reJWMyO2hiN9/AooSGdEwTKkC"
                "D7/biu6HfiZ638rIIVwQ+Qzpg6BFMzS2UcjlyItOQObDZ8i4G4GkU5dQWlxCPpfnMbi/9H9o"
                "vf5r4mvKkLxMJloAWPh4otGsqtW4VcjlSLtxH3H7jiHp1CWia0py8/Hm4k249egAQCnA/fv3"
                "h6Wlpc49hF+9eoVx48aBYRh4enrir7/+0kvoj1wux6hRozBt2jSEhIRgzJgxGDNmjM7HoVDe"
                "N4xqgibd/Vo38CMWEa6AD7GXG9x7haDbgZ/Q8bd1EHuSn3e9PH6BqJ1CLsf1mUu0Slbh2qUd"
                "eh7biXZbV8C5fUsi8QUAcw9XNF/+OXoe3alVMpHsJy/w6kQ4cXuA/DOxacSevYhrYgLrBnXg"
                "N3IAWq//Gv2u7keTLybDxJw8z3DikXNVOqYgfx11te67DK6JCZw7tEK7zctQZ8yHxNflxSSg"
                "uLgYOTk54HA4GD16NPr371/leahjypQpyM7OhkAgQFhYmMojWdfMmDEDf//9N3r27Inbt43r"
                "A0Gh1CaMugPOIXTAIrnZq8O5fUt0Dt2Mcx9MgTQ1g7V9+s2HkOUXsJo9n235g8jECSjNnIHz"
                "psJ/wjCi9uqw8PNEt4M/IXzkLOTFJBBd83j9drj36kRsVid1irOugnCZ2lihwdSP4NG3C27O"
                "Xoqsxy/YL2IYRKz+CZ3+2KDVWMSLu4ZVF2AVHA6aLZmN9NsPkfsijrW5NDUD69atw4YNG7Bo"
                "0SLMmTNH56X3/vrrL5w8eRJirgkWT5wK+5gURD7cAzNne1j4esG6nq/KDF4VFHI5Cl69gSTx"
                "NQa4+SPNuQ7q+vrCLiENr3OugG9lAQsvN5g5O+jwVVEYhQKFyakoeJ2K0kIp5EXFUBSXgCvg"
                "gyc0BV8sgsjVCSIXJ3B4ht9fleTmozA5FUXpWZCmZaIoIxM8U4Eypa61JczdnJWJg2pQEpZS"
                "aRFyYxKRFxUHaXomhHY2EHu7w7pBHfDFus1N8C5GFWBd7rY0YeZoj4C5U3Dry+9Y2yrkcmTc"
                "ewyXkDZq22Q9foHn2/4iGpsnNEX7X76HU7vmxPPVhKmNFdptWYazH0whSmUpeZmM9DsRcGzT"
                "lLVtqbQI+XHsGbB4QlNY+noRzbcyxJ6u6BK2FZfHz0XazQes7VOv30PqtXtwCiZ/D4kXd7oQ"
                "4H9xaBFAJMCFuXn4fsdaFBQU4NSpU/j888/Vtn2wfCPS70Ro7K/h9DFw7xWi+n96ejrWfTEf"
                "37gGoJGZNXDmAe6deft9brZ0Dup89AHrXMuTGxWPl0fPIf32I2Q9jnzrOGSEuSuQWoR7C9e+"
                "dY2Zoz3smjaEY7vm8BrQvUrn+feWbEDmfc2Vobof3s7qI1IeeUEhLo79nOhIp/7kkfAc0I24"
                "bwCICzuGmD8PaWzjM7g36n48RGObUmkRUm/cx5tLN5FxJwL5CUlEc+by+bCs4wWn4BZwCWkD"
                "x9ZBehO93Oh4JJ+/huTz15H16DkYhUJje1MbK2U63e7t4dmvq1Y+N5URt+8YYv7S/F67dgtG"
                "49kT3npMmpaBx+u2I/GfM5XO2WtQD7Rep1+fCeMKMGGcZnUFGAA8+nbG/WU/EDnNaNopK+Ry"
                "3J67EkxpKdG4rVbP15n4lmFZxxuNZowjDjd6c+kWkQDnRMay/ngAwLqeX7VX11w+H8E/fotz"
                "Q6cSpb2M23dUKwE26A74X2wDGwC7/2FtZ+HsiAsXLuCzzz7D1q1bNbZNuXqXdVHEK1e+TyGX"
                "Y9eAsVhg4QdNt1ttflNvwm/gycZdyH5CYLF4B2laBpJOX0bS6cuIWLUNngO6ocGno7U6SinJ"
                "ymW1NjHyUnAE5N/JuH3HiP1DJImviftVToZB5M97NF7H4XHh2rWd2uelaRl4sWMf4vYegVzL"
                "nPEAoJDJkPM8BjnPY/BiRyis6vmi4Yxx8OgdonVf6ki/E4FHK7eQWbLKUZydi6RTl5B06hKe"
                "/O9X1J8yGr7D+2m1gCpPxt0I1u+Ha9e3w/uidoXhyYZfNb63utAdNox2BiwvKCT6YvNMBbCs"
                "U/XdVhlcvtLjmARN57ovj5wjNv82nDEOHn27ELXVFr/RA4l3EymXbxG1IxatapyblodvKUaL"
                "b8lSXiafv1ZpDG1lFL5JI0qEYu7uDIGVBVGfJCjkcqJ2Zk72aNWqFa5du4a6ddW/lwqZjOg3"
                "InJzBqA0Tx4aMQ3e6YUaxZfD48K6vh9rvxl3H+PCiBm4Mnl+lcT3XeTSIsTtO4bT/SYi4eAp"
                "4uv4BJ8R6Xtf1vbFzjDi9iV52iWGSblyh/Vzc+/RsfJFCMMg8pe9OB4yAlE7w6okvpWR+yIO"
                "N2Yuwd2Fa6GQkTlyqqPgVTKuz/gG4SNnai2+FfpKSsG9xetx9ZMFkOVJqtRHXmwiaxtzt/9P"
                "bvNi+148/G4r63tr0/g9FuDsZzFE4UJW9f2qbaIoQ+hgS9RO7Q+OYfBieyhR2wbH7wAAIABJ"
                "REFUHxZ+nmg0cxzp1LSGLzaH14DuRG1zX8QROYuRnv/qcmXo0DKAyEJQWlzCaoYswxi7X4B8"
                "p7Tr0hlkZ7N7zucnJBFZWspuLje++h6lD9lviJa+XuCZqc+CpSiR4fbclbgwYgYy7j5m7U9b"
                "5AWFuP3V97j3Ddm5voCgupRCRi7AL4+cI4q+KKNES2GI/vMga5t6k0dWeEwuLcLVTxchYs1P"
                "xNEO2hIXdgw3P1tR5etTrt7B6b4TiL3+SXlz8SbODpqsfew/wyAvhl2ARa7KRWpc6FE8Wv0T"
                "e78cjk6Pp9RhNAEmDXfRqRmAMD5YXQWbNxdvIjeaLCY3aMF0nS0c1OHQOoi4bT6BOJB+JroW"
                "LrZzsDLS72k+Cy2DNAWlTn9gDIPkc+y5uDPlxVj1+w5cuMDubU9yYzG1tYaJuQixuw8j6Z8z"
                "RFPVZMEozszGxY/mIOHQaaK+qkPsnsNEGehIyjsypDtgLRbRZci0SI1akPQGKZc0W5wcWgXB"
                "NqB+hcfvLlqrs3zumkg6dQkvft2n9XWJh8/i6qT5xJYobZG8TMb1md8QH+8BSmsXyXzEXq7I"
                "iogkXvRZeLtrFa1RVYy3AzaCAJPG66rbKUf+spfoesc2TTU6cekKUpM6oLyxakIhkyE3OoG1"
                "H66JCazr+RKPS4Jjm6bgEhQFyI97RdQfaQYsXS4kYnb/Q2QKe1XHEd26dcPgwYNZ2+YRfB6W"
                "fp4oSs/Cg9U/kkwTgPrfVG50PM4N/hQZ958Q91Vdnm3+Ha/PXtHYRmBJYIIm3AEnh98gXkSX"
                "oU1u8pi//mH1o6g/eUSFx+JCj+LlkXNazQtQHq1VZaH/dOOuCmU1NRGz+x/c+vI7YlO/0MEW"
                "jm2awndYP7h2DVaGghI4gWXcfYynm34jnhfJIpVnKoCZswPufb2OyMcFMMz5L2BEJyxSByxd"
                "3iRJf3hC+4oCLElIQvqdR0TXaxMTWh3MnOzBMxUQJbcoYhHg3Kh4orMhy7re1QpfqQwTkRns"
                "mjZifX8LX6cQ9WfIxR2jUCD6t/14tHob+3gN6+K7Qz+jhPAmRuJrIPZ2x4NvN0NRSH5WWNnZ"
                "VnF2Li6Pn0tsmrWo6w2fgT1g4ecJc3cXCO1sIEl6g7yoeKTdfqiVmESs/QWuXYLVOvaR7IBJ"
                "heHFdvWLaA6PV+nuS5ZPZoIuLSpG/P4TGttY1vGusDhnShV49uOfrP1zTUzg3icELh1bw65p"
                "I5jaWSvDZBgGxdm5KEhKQeLhM0g4eIrV2VReKMWLX/ehyReTWcfNevwCD1dsJrIgilydEDB3"
                "Cjz7dakguFmPnuPOwjWskQJRv+1HvYnDiT53ot+Ipxti/jxIrDlA9fIDaINRBLi0uIRo5aLL"
                "3VZ+/CsUvibL1WzdoE6Fx96wmJXKENrbaPRu1DUCK0tI09jjm9l2wKRmW12bn8uw8PFgFWAS"
                "C0ZxZjZRvLepnQ3MnOyJ5/cWDIPcqHik3biPmN3/ID+efWcu5QH1vxwPDo8HU8IdS05kLGub"
                "vKgEZD6qWGXJ0s8Ldk0bQuhgBy6fj5LcPEhTM5D9JKqC6Z1RKHDrsxVE4lsiMIHT5KHo/tmn"
                "FZ4TOtrBvllj+I7oD5/BfXBn4Wqi31x+3Mt/M9D1qfR5Xe2AMx88VRvSJXJzgsDSolJvWtId"
                "8Muj51l3lfUmjaggTG8u3mDNI29iLkLwj99WHgnA4ahS2doG1EeDKaNxccxnrBaZV8cvsAqw"
                "XFqEW5+vIFrg+I0aiKBFM8AzrTyjm21gA3Q/vB2Xxnyu8bcuLyhEzO5/0GDqR6xjkuZiePK/"
                "ikcdZo72cGgTBDNHe/DFIpTkSVCcmYOcZ9GwCWhA1G91MYoA576II7Lz63K39fyn3UTtbAPq"
                "V5o8gNST2PvDXkTmVF0hsCETYEWJ5h8QqdlWX6YZgTX7TZaktjLxKlehwO2vvidrKpOhtKgE"
                "cqkUhW/SUPg6Vas6w9koxbcJD2A6YRyioqKIkm6USosgSUhibfeu+Lr36YwmcybAwpc8r/Sz"
                "Lb8j5eod1nZCRzv0Cd1ClFnOKbg5uv79I050HU0Ur5545KxaAeZb6WYHrOkIyXdIXySHX6/0"
                "OVInrBgW5yuhox28BlaMJ069zl4EptGMscRheEJHO4Ts3oiT3UZrTMcqeZkMaWqGxoXow++2"
                "EC0wfYb0RvPl6uPZy+CamKDpktk4O3ASmFL15uCkU5fIBJhgkfqu5dOuaSMEfDUFDi0CjJ4Q"
                "xCgCbIg0geV5ffYKcdiDe4+OFR4rLS5B2q2HRNc7d2il1dyqC2luX75Ys0MB8Weipx2wwIq9"
                "XJ2cQPRIX0dxdq5WoTBVxa1XJ8RaA1n/e4C/1q4lzniV8yKO+LwKAEoYBUQTBqHdoi+0ml/O"
                "8xg82/IHa7tSAN5LZmiV1tXM0R71JgzDs63s/WfcfQy5tAgmlXhnCyxInLA0L+jz417i9bmr"
                "lT7H4XHhM7QP3ly6Wenz8oJCMKWlGs9aMx88ZV38+Y8bAi6/4oaCxPLgrKVPidDeBl4f9Hxr"
                "UcAzFcDMxRHmrk4QuTpC5OqkcSOUF5uIuH3HWMcyd3dG029mE8/Nur4f3Ht0xKuTF9W2yYmM"
                "gUxSoDETlaJERuQnUZ4mn09Cg2k1J0+5UQSY2Eu1mrstplSB2NAjxOcXXBMTePSrWKot/fZD"
                "oh0P18QEdk0bVWmuVYU0TtBEgwAzpQrkEGRw4nC5sG5Y0TyvEwg+HxORGWub7CfGry/N4fHg"
                "EtIG9SePhH2LJggGMGHmdDg5ObFeW4Y2+a9LGQYnHHnYo6X4AsDzH/8kEvpjhSkIruRoho36"
                "n4xE9J8HWWM8FTIZMu5EwLljxQUsn8QEzRK2E7k9VO13zLVzO5g5O2gU2JI8idroCIA99MjE"
                "XAS/kQMqfU6awm7BYltgVEaDKaPg2DoIIjdnmLs6wtTWWqsdX9TOMKLfZePPJhH9NstjWdcH"
                "0CDATKkCWQ+fw6l9C7VtcqPitIr/Dlo0A/7jh2ozTb1To3fA1lUU4MLkVCSdvoT4sBNaeTzW"
                "GfshzN2dKzye9ZAsY45tQH3iAgu6gjR4XdM5Wn78SyIzodjLTesfGikkiTNIkmYYq740V8CH"
                "S0gbOAe3hFv39hA62mHmzJnok94HvXv31kp8AfJUmgAQmp2ApfsPaztl5Me+RNLpy6ztFGIz"
                "fPDdiiqVSzQxF8G+aSMiH4oCNU52RHHAGm7ERWmZSNQQouX30SAA0JiJSaZBgIsyspF0UnNc"
                "rO/wfmqdikiO2eIPnETTr2eytiuPmbMD3Ht10uqaMoozszW+Z2UIHe3g0bez1v2be1ReyrQ8"
                "0nTNuQu0capy7xVS48QXMIIAM6WlRPlyASBu7xEkEsQjlpbIIC8oRHFWLvKi44lu5u9iamOF"
                "RjMqT5yRF8+eKhEAbAMbaj1udSgtKiZ+reYaTIfGCAl7FyIBZjFFyvILUJD0RldT0gpFiQxZ"
                "j56Dy+dD6GCL+9IsbNmyBVu2bMGff/6Jjz5iP88qD+lnklhSgIJm/mjalD3V6Ls8/3k30e43"
                "8JPRaDC86oVErBvUJRLgYjVOdmWFBjRZoRQadohRv+9X6+Fv4eMB5+AW/46j/naoyRErbt9R"
                "jREEHB5P482fxBkw+rf9gEKBgHlT1To56ZKY3f8QRVd49OlcJZ8XkYsja5uSHM33BNLfiImZ"
                "EM1XsJ9PGwODC3BeTCJxTVhDJAMAlGdALb6bq3aFKiFwQgAAsbebLqfFCqlXN6AMLFcHqdlW"
                "n675JALM5oyT/SyaONmKPpCmZuDV8Qt4dfwCuFZifODdEA9QSBTzWx6FXI7cKDLLzcHsl9i5"
                "mT2E5V1KcvKQePgse0MOB74jqlcqkcTBDtAcKse3FGsUYEaNF7RMUoDYPeqtA3XHfqgyy/KE"
                "6rODqcuOx5SWauwfADz7ddEoOFb+PhqvLyP6j4N4fe4aPPp2gUevTsrc43ri5TGysqwunVpX"
                "qX8Sk7osX7PTJamVyO+jDzQeHxgTgwuwsUyEmmjx7ZeqAumVUZBEFn8q1iLBvC7IIszPK7BW"
                "lgJTR84z0sQV+tsBS9+ksbYRe6lfRADkmbwMgSJXghE8e0xuFQCBxszMFcmLTiCKyU6XF6Hb"
                "nClo0ED7G3Fy+A2iSIQCOwvl2WE10JT2khSBhVhjOlV1Jui4vUfUxsTyLczhPbi36v8mIvXz"
                "VHfU8/rsFdawt3qTKibeKI977xA83rBDY5syCpNT8WL7XrzYvhdCexvYtwiAffMmcGgZoLRQ"
                "6cCrt/B1KlFVNAB4feYKcYhmeQpeJrO20eQ4ypQqiDygOVwu/MeTZdozBoYXYC3s9vqGw+Mi"
                "aOEM+Aztq7Edaeo1TSKnD9IJPbMrS3ungmG0qEqlnx1wSU4e0Y7PliU5Omkua3N3Z/AJPGvL"
                "KC0qhlxahOLMHK0T2effjsClj79Ep9/XE/sHkL6OSFMF/rdkiVbzKePNhcpDbt6l2UjtShZW"
                "BmkqR03vD9v5f2UCrJDJELVrv9pr/EYOeMunQdN3Qp0Jmq3koFP7FpXmFSiPhY8HnNo1JwpH"
                "Kk9RRraqqhDwbw6CLsFw7RYMp3bNq+yPknab7L4CALF7j1RpDBI03U/z418SOcY6tmkKM8cq"
                "xvsbAIMLcE3ZpYg9XdF6/dfsXssMQ2wy55kZ1gEr7RZ7LV0AcGgVqPY5yas3RCUaRa5Oeltg"
                "pN64T1YGkeUMmtS60nbzctg2qUfUtjxMqQKFySnIfPgcyeevIenUJSIvzIx7j/Fg+Sa0WElW"
                "+Yn0dfSePxsmVYw5z3xYMXlHZXi+U8atKrBlYStDk4MfW1akyhJxJP5zVm2MPJfPr5CDXJOj"
                "YmWLiNzoeNbwxPqTKhZdqIzmyz/H6b7jie81lVGUkY24sGOICzsGntAUHr1DUO+TkbCqS2bi"
                "LkMXla90gab7DelvxLN/xaiWmoRhc0EzjLIKkhExMRPCf/xQ9Di+iyhkSJsqK6Qxubqg4FUy"
                "cfUdxzbN1D5XExywUq/dZW3DMxXAqq632udLpUXIJ3CWq052NQ6PC3MPV3j274o2P3yDXqf/"
                "YN3dlBEXdoy4shDJIrWIx0Gf8do5dqmuTc9CIYHJn8Pjwcq/+pnoSCvcaDonZRPgCmfADIPI"
                "HeoTb3gO6FZhZyTQ4GNQUkk6Srbdr3WDOhrDaMoj9nZH6w2LdVbApbSoGAmHTuN0n/G4+/U6"
                "rQoo5DxnN+0aAk3OaaR+K45t1d/7agIGFWBJ4muibEb6QOzpiqBF09H/+kEELZpRacB/ZZR5"
                "YJJAspPUFfH7TxK1EzrawU6DswapI4O+zM+KEhmSCcyhTu1barw55UTGasysU4Yus6uJvdzQ"
                "Ycdq4pSWz3/6i7UNo1AQpddzbKneqsEG6cLNwttdJ+8VSZEKQJkOUh1s6SjftUS8Pn8N+bFq"
                "FmQcDupNGl7hYU11h981QcskBaxhOmxnv+/i3rMj2m1eRpQDmRiGQVzoUZzpP5E13WUZhclk"
                "Pi/6xsLHQ+1zJH4rQkc7mLuzhzsZE4OaoA3hgMXh8SCwtoTQzhq2gQ1g3zwA9s0ba/ww2TC1"
                "sSLaMWhTNaU6MKUK1qTvZbh1b6/RMcNYtXPLiPv7OFGtYjZTkrHOsc2c7GE1ZRiky9mrEaVc"
                "ucOa3UcSn0SUXMWnU9WrbZF8lwHlYqW6MKUKolSGADSaSllN0O8I8AsNaSddQtpUOpameON3"
                "TdAJB05p3FWKXJ2UBQm0xK1HB/QKaoAHyzfj9ZnLWmVD04Qk8TXCR81GtwPbYGpno74hwxAl"
                "BtE3Qkc79UcShH4r9s0a63hWusewAkx4k/QbPRD1J4/Sqm8OjwuBpVgvNRxNba2JblrahAVV"
                "h+Tz14gKDgDK3NSaIDZBszhAVQVFiQzPt7HvCk3MhHBjOYs0Vi7r3NxcjF+6AN/AFWZczeZD"
                "prQUGfeeaAzdIF5INNb+DLuMogwyk7CpXfW8nwFlFTGS4vIiNye1ZUAB9mQcjOz/Pboz7j7W"
                "WFKxsnKAgOaMW2+ZoBkGMbv/0Tgf//FDqmxONnO0R7styyBJSEL0nwfx+uxV4t2rJgqS3uDR"
                "6p/Qas0CtW1kBYVEfg1cExOdLNDUoWmhXJBE5reij3uWrqmRO2DHVkGVZqQyFqQ3ooz7j+E3"
                "eqBe56KQyxGx7heittYN6sBOQ3IQaUo6irNyWPsxtbPRiydhzO5DRHlw3XuHsIaykDr3VTW7"
                "mjpEIhEGDxmC2N2n0diM/XsiTdX8eg1xJl9aTFZIQhtPcXWk3SRzFGSrbc3uhPX/Ih/5yx61"
                "7WwD6sOhVVClz2nytC6/A069dk9jmA7fUgzfYf00TZcIsbc7mi6ehaaLZyH3RRySw6/jzYUb"
                "yHz4rMo744RDp1F/yihY+nlV+jypz4uVvw+6HyELndI15JuGqi9SDYVBBZj8vLFmrVxsm9RH"
                "yuXbrO3UlTrTJTF/HiSO0fOfoDl7kTHDjzIfPkPEGvaFBIfHZa2KopDJkEuQlJ3D5RI7TZGQ"
                "kZEBe3t7rFmzBqezGOReZP+OlLLU7SXJk27u4Vqtc8LSIjJPWxPT6nv1vyGsIubaRXMJT9Yz"
                "4H8FWJKQhOTwG2rb1Zus3itZ0y5bXu5zi92rOfGG36iBOrfEWdXzhVU9XzT49COU5OYj424E"
                "0m8/QvrdCGRFRJInoGEYvDx6Ho3nTKj8aUIBFla1lKcOIA3Tq2k6UhkGc8IqfJNGlu1IbA6x"
                "l2EzSrFB6klXmJyqdSyfNuTHvcTTjb8RtbX084LXgO4a2xCbbXWcgKMoLRPXpn1NFFPrNbAH"
                "6/l9LmHiCgsfD2LnOzbWrVuHRo0a4fZtpegK5WQ7ErYbF8miqLo3FtJ83rJqOkwqZDKk3bjP"
                "2o4r4MOF5UybbcFRFr4T/ccBtWIk9nSFe8+K1c7+fwz1Il/6rxm9KD0Lr89dU9uOy+fDf6x2"
                "mc+0RWBlAdeuwQhcMA3dDvyEvuGhaDRrPIT2Gs52y5F6RX3pSdKkKVy+UcoIACDbAYtcHGts"
                "9qvyGEyAySsg1TV6jcZ3sWvaiDj/avRv6gP/q0NJTh6uTJ6vsb5neQLmfQoOT/PHS27K0d0O"
                "WJqagSuT5xM5XnH5fDSaWXl+7vKQmp91dSYUExOD+fPnIy0tDdOmTYNCXopcgqw8gOZQm8LX"
                "qawF3YHqfx6mNmTx3NV1Knx14iJR+IvP4N7gW6h3TAMIzoAVCsilRUg4qD59rf/E4RoLLvAt"
                "zNXee0qlytcR//dxjRnEvAZ2g9DRTuNcdY25uzMazfoY3Q/vIFqcaaofzheLWO8bAHlyFX1A"
                "oiW1YfcLGFCAa7PdnmcqgANh2Efyhesa61xWBVl+Aa5N/Zo4fMR7cG9Wkx5guLKQZaTfeYSz"
                "AycRfxeafDEJ5gTpPQ3tgFWnTh3s27cP3t7e2L9/P1Iu30KRmkIC76JJgA31GyFNqEISDqUJ"
                "tgL1gNKZp8Gn7PHMJJWwXh07r3aBampjBZ9yaScrg8Plql0IyAuLwCgUiAvTUB+Xw9E69EiX"
                "mDnZo/ly9qIDGi2RHA7R2X9BVRxOGQavTl4kWmSqQ5qWQfRbqw0OWIBBBbh22+3ZzlPLc3fB"
                "Gq3KIGoiLyYB5z6cgvQ7j4jai1yd0HQxe9my4uxcIs9uvoV5tWPp5AWFeLrpN1z86DNioXJs"
                "0xT1JlaM1awM0rPs6jpgRUVF4fJlZfm+wYMH48WLF3C1scP9ZT8QXW/mZK/R09dQSVHUOeC8"
                "S87zGOJyl++SevUuUbYtrw96aoz/LYNEFGJDj6p9rs6YD4ni+dXttBUlMqRevasxL7xLSBtY"
                "1vFmHaMySqVFyImMRdLpy8iLSahSH4ByccZ2zMK2mCH5fkhT0rV2BHt99ipuzFyCw60HInzk"
                "TLzYEUocolaGsaId9IXBDPnGDHfRBc4dW8E2sAGyHrHXBpZJCnBh6HS03vA10U60MkqLSxC7"
                "5x88+d9O8iw2HA5arVmgMc60DOLPo2HVjwTkBYWI/v0AXuwM02rVK7S3Qau1C4nGJU3KDg5H"
                "+VqqSFpaGnr37o2kpCTs3LkTo0ePRvGrFFyftYQ4/Mx3eH+NJlCShYQuzrYsfD3BsbUEk6X5"
                "M2FKSxF/4KTWdVTlhVLc/XotazuuiQkaTiPL5sW3ECu/D2rOd3MiY9X+NnlCU9QZQ5bTWmBp"
                "gQJUFFlGoUDcPvUCD6gPbyqPXFqElMu3IUlIgiTxNfITkiBJSFLWvv33tbl0ao0Ov64hmu+7"
                "FGVkscaRi5w1lwJ0bNsMGfc0Z21TyOVIuXKHuBoSo1Dg6aZdyn+XKpB+JwLpdyLwaNU2WPh6"
                "wrVrMNy6BsOuaSONJnBDW+30jUEEuDgrhyjcxMRcVK2EGfqm0cyPcWXSPKK2MkkBrk5ZCPee"
                "ndBwxlhY1/cjuk6ako5XJy8icvteonPS8jT5fBIc25DVhc0hXElqUwFJIZcjLzoBqdfuIvXa"
                "PaTfeUSUML08AmtLdPp9A1G9UODfpOwEiSvEHi6s54yayMzMRG5uLiCTo+hpDG598R1enQwn"
                "inEFlAlifEdoDk0hWRTp6sbi27szYndr9uYFgOc//gnPvl2IzzUVcjluzllOVEEs4KspREcM"
                "gNIbnm8uUmtiTj6vPpuaz+DexIsWddmwGIVC4xiawpvKw+FycWfeKo2+HG8u30bO85gqeey/"
                "uXSTtY1YQ2lSQCnAz7b8ztrP0407iQX40aptahfK+XEv8SLuJV5s34uuf/+oMUUwiSVV6Ghn"
                "8HP4qmIQASYOd2lYp8Y5YJXHJaQN3Ht1UlUfYYVhkHTqIpJOXYRlHW84tWsG64b+MLWxBN/S"
                "AqVFRSjOykFxVg4kiclIvXFPffo8FhrNGs8arlMe0s8k+cI1jcKgkMlQnJ2L4qycKpsry+Bb"
                "mKPTb+tgpUWuZtKdPFcgQNSuv4n7ZeRylBaXQJKTC25RCYrSs7AjsDuKX70BJ+wCyJIr/j/e"
                "H/bSGEtdlJFNtOCqroWosLAQf/zxBwZ/2Auxe46whq8UZ+fi8sSv0OaHb1hNk8WZ2bizYA1R"
                "alG3Hh20OtYBlJ7Q6oRLnWMUh8uFP+FRBqDZPKspQYWm8Kby8EwFcO/VUXMqWYbBpXFfoOPO"
                "NVqd92fcfYxHK9kzsmkqvQoADi0CIPZ2hyQhSWO7rIhIRP6yF/U/0fzao3/bj6idYazz8hzQ"
                "jTU/fzZBCsrasvsFDCTApLutmuiA9S6t1i5Efvwr5L6I0+q6vJiEap3taKLhjHFoNOtjra4h"
                "FS5J4mti56/qIPZyQ/CP32olvgC5b0FeTAIefrelKlN7i6osD63r+6HZN7M0tsl6EknUV3Vv"
                "Lhs2bMDixYux2tsbv/cbg5ST7IvJnOcxODtgEhrPmQCXLu0g9nQFl6/MES3Lk0Dy8jWSTl9G"
                "7N4jREcNYk9XtFqtPhuTOgSWYq0zQrn37AixJ3md7qokHzH3cIV7D/XhTe9SZ+xgJBw8rfEM"
                "tTgrB+GjZsNnaB/4DOmjcTec8zwGL4+dR/QfB1mtQSbmIriEaA754vC4aDj1I9yet0rzCwEQ"
                "seYnZNyNQNDC6crw0X83UExpKbIiIvFo9TaiIiQmZkIEzpuqsU1JTh7RcQ8V4HcgT69X8984"
                "EzMh2v/0Hc5+MKVa3nw6gcNB4zkT0HD6WK0uk0kKICEoiG0oXLsGo/W6RVUyEdeU8pbq4FuY"
                "o93WFazxlYe2bocDQX/VvbmUOZHVrVsXLRZMx6nLd4gKpJQWl+DR6p/waPVP4PC4MHNyQElO"
                "nlZVdgClk2D7X76v0mddFXEk3ZmWQeJtXWGMicOIQnfKsGlYFz5D+yBunwaPaijP0qN/P4Do"
                "3w/AzNEepnbWMLWxAt9SDLmkEMU5eShKzyROSwsAjWePJwqp9BrUAy927CNyJk2+cB3JF67D"
                "xEwIy7reUJTIkBf7Uqva2Q2mfsRa1MTYdcv1gWEEuBaHIFWGuYcrQv76Ademfo2CV8YRMlM7"
                "G7RevwjO7VtqfW3Os2jyzDl6RGBtiSZfTIbfiP5VO3ogTMpuLCz8PNFu83LWxDLnz59H/NVb"
                "cDDXfAPSxdnWmTNncPDgQfj6+kLk6oR2W5bhyqT5GmNb30VZF1n7MBTbwAZo/9NKjZ7gmtBW"
                "HB1aBcE2oL5exxBYW7KGN1VGwNwpSL/9iNgLWJqWoTF+lwSHloEVaiCrg8PjIXjbtzj74RTi"
                "oyW5tEiZlUtLHNs0RT0WMzagTbx/7dARwABhSKS7LRMzYY12wHoX6/p+6HF4O1w6tzX42N4f"
                "9ESvU79XSXwBcrOtvuBwufAd1g99zu2G38gBVT73l7wiS8puDDwHdEP3Q7/Ayl9zMfQnT55g"
                "2LBh8BKw7+6qs/tNS0tDZqbyjPnDDz9EUJDSYci5Qyu0+PYLjd7ZusCjdwg6795YZfEF2LNh"
                "vQuJV/K7sKW8fJc6Yz4gzh711jjWlujw6xqY2la/4AUJ9s0ao92PK7T6nMXe7mi7aSlxOdaq"
                "YN2gDoJ//BZcE/a9IMli29TGitiBsyagdwHOeR5DtNuyblhX7zcBXcO3FKPDL98jaOF0g6Q9"
                "c27fEl1Ct6DV2oXVGs8QZSErQ2BlgXqTRqDPhT1osXIucUIIdZDUBDUkHC4X7r06oev+bWiz"
                "YTFrysfY2Fj06NEDxTl5cOKz38SrI8ALFy6En58f1q1bV+E5n6F90enP/8HMmcQIrh1iT1e0"
                "3bhEJzdybQTYqq4P61lndcfgmQpQd8yHWo9RhtjTFd0P/cLqeFRdvAb2QKc//1ele4Zz+5bo"
                "+vePeqmr696rE7rs20L8npNsHGrT+S9gABM0ceB0LTj/rRQOB/4ThsF35ADE7T2iDB9KJyv3"
                "RgLPTAjPfl1QZ/QgnZlWSIti6AKBtSVcOrWGS0hbuHULrtJuQR3ZT4xvfuby+bBr2ghObZvB"
                "c0A34jzmycnJ6N69O968eYMmIrIcvlU920pJScEff/wBmUyGuLjKnQe3vokLAAAgAElEQVQd"
                "Wweh57GdePK/XxF/4KTW4WPvYmprjUYzx8F35ACi3Q0J2uxO600aXiXLijYmaO/Bvau9gxW5"
                "OaFL6GZE/3GwSqGHmnBoGYiAeZ/CLkh9RTQSrBvUQffD25Xfjb+Pq/JuVxVzD1c0+WISPPtp"
                "rvFdHnmhlNUrG6hd5mfAAAJMHDhdy964dzExE8J/wjD4jR6EN+E3kHbzAdJu3EderLYBK8rc"
                "rg6tm8IlpA2cO7QkSqxBSmlRMfLitJ+TWjgcmIjMwDcXwcRCBJGTAyzresPK3xfW9f1g07ie"
                "Vg4q2qDvnTyHxwXP1BQ8MyF4QgEEFmKI3Jwh9nSF2NMVFn5esG/WWOudXWZmJrp37474eKWD"
                "yxejxgHh7EULqvobcXZ2xo0bN7B8+XIsXrxYbTuBtSWaLfsMjeZMQMyfh5B06qKyyhShv4C5"
                "uzNcOrWBc6fWcGrXXOemS7Z80GWYOdrDc0C3Ko3BtyIbg8Plop6WYVRq++Lx4D9+KPxGDcSr"
                "4xfw+txVpF69q7WDGzgcWNf3g3uPjnDr2ZH1+EMbBFYWaLZ0DhpOG4MXu/5G8oVrWoVM8oSm"
                "cAlpA48+neHWvb3Ki56UnOcxRJm3dJm33hBwBk5exoRtXQiBEatbvM8UpWch89EzFGdkozgn"
                "F8VZuSrvUa6AD56pKUztrGHu5gxzDxfYNPKvFVU83gfu37+P5s2bA1Cmlty/Xz+FNMqTn5+P"
                "Ll264O7duwCAVatWYd48suQuVUGhUIBbjaOdkpw8ZNx7jLzoBBTn5qMkJxdySSH4VhYQ2ttC"
                "aG8DUzsbWPv7wsLPU4cz/2+jkCk9ifNiEpAf91J1z5BJpKqkJCbmZjARiyD2cIVlXR9Y1vHS"
                "WbUvEorSs5B++yEKklJUuQDkhUXgi81gIjaHwFIMCx9PWPn7wMLPU2eWkPeBEpkcw6avNGw9"
                "4P8iQgdbuHVrb+xpUMohlUphZmaGZs2aYfLkyTh9+jQ+++wzvY+bl5eHAQMGqMR33rx5ehVf"
                "AOjZsyf8/PzwzTffwNWVPB62DIG1JVy7BsO1a7AeZkdRB5fPh3V9P+IMesZA6GALj75djD2N"
                "Wk3t8nqiUKrJH3/8AW9vbzx58gQAsHHjRjx8+BDBwfoVmMTERAQHB+PSJWXii08++QSrVrEn"
                "OqgOp06dwrlz5/Dzzz9j3759eh2LQqFoDxVgyn+G7OxszJ49G2lpaRg7diwYhoGZmRlsbMic"
                "oKrKzZs30apVK5XoT5w4Edu2bdPrmAAQEBCAiRMnwsvLC1Onas4yRKFQDA8VYMp7TVpaGlav"
                "Xg0AsLGxwbJly1C/fn38+uuv4Bgg73hoaCg6d+6MtLQ0cLlcrF27Fjt27KjWuSwJSUlJcHV1"
                "xY4dO/Ds2TMIhYY7G6RQKGRQAaa8t9y7dw9169bF/PnzsXv3bgDAtGnT8OjRIzRtSlY1qjos"
                "W7YMI0eORFFRESwsLHD48GF8+eWXeh83IyMDdevWRadOnRAfHw+RSKT3MSkUivZQAaa8d6Sm"
                "KtMkBgYGws3NDVwuFy9evAAAmJiYQCBgz4VbHTIzMzFs2DAsXboUAODt7Y3r16+jXz/N5Qh1"
                "xfr161FUVITLly/j4sWLBhmTQqFoD/WCprw3xMTEYMaMGXj27BkiIyMhEomwa9cuCIVCBAYG"
                "GmQOe/bswZw5c5Cerqx/3b59exw8eBAODrrPMqWOJUuWQCAQICMjA+PHjzfYuBQKRTuoAFNq"
                "PUVFRRAKhUhJScHp06cBAFu2bMFXX32F1q3JCoZXl8TEREydOhUnTyrrvHK5XMycORNr1qzR"
                "+467DIZhIJfLIRQKsWzZMoOMSaFQqg41QVNqLWFhYWjevLkqlrZ9+/bo3Lkzli1bhpkzZxpk"
                "DgqFAj/88AMaNWqkEt/GjRvj+vXr+OGHHwwmvgCwY8cOBAUFqUKdKBRKzYbugCm1ioKCApib"
                "K1NzHj16FPfv30d0dDRWrFgBS0tLnD9/3iDezYCytu7cuXNx+/ZtAICpqSkWLVqE+fPng69l"
                "qr3qkp2djfnz5yMrKwufffYZ7t27Z7D3gUKhVA26A6bUCtLT0zFr1iw4OzsjMlJZc3Tu3Llo"
                "1KgR1q9fD1NTZd5hQ4jOyZMn0aFDB3Tq1Eklvu3bt8fDhw+xePFig4svoAyx2rx5M1xdXbFp"
                "0yYqvhRKLYAKMKXGUlBQgKgoZcEFLpeLHTt2QCKRYMOGDQCUiSaePHmCyZMnqwRYXygUCuzf"
                "vx/NmjVDnz59cPXqVQCAnZ0dtm7disuXL6N+fe2Kv+sKiURZMH3UqFGIi4tD+/Y09SmFUhug"
                "AkypkaxYsQKOjo4YO3YsAKXQffLJJxg/fjxmzJhhsHnI5XL8/vvvaNSoEYYOHYoHDx4AANzc"
                "3LBhwwYkJiZi2rRpRttxxsXFwdfXF1u2bAEAvS9EKBSK7qBnwBSjI5PJcO7cOezbtw8bN26E"
                "lZUVbGxsUFhYiFu3biExMRFeXl744YcfDDanO3fuYO/evdi3bx+Sk5NVj9epUwfz5s3D2LFj"
                "DepgpY4JEyYgPT0dX3zxBXr27Im6dWtXOTYK5b8MFWCKUZDL5ZBIJLC2tkZkZCT69OkDAAgJ"
                "CcHHH3+MIUOGIDIyEiNGjICnp2HK3D19+hR79+5FaGgoYmNj33ouMDAQCxYswJAhQ8Dj8Qwy"
                "HxJ+/vlnDB48GFOmTKHiS6HUMqgAUwzO0qVLsXXrVgwZMgTbtm1DkyZN4O/vj/z8fBQXFwNQ"
                "FpEvM6vqk/j4eISGhmLv3r14/PjxW8+JxWIMHDgQY8eORY8ePfQ+F22IiYlBnTp1UK9ePdy9"
                "e5fmeqZQaiFUgCl65d69e9ixYweeP3+uSouYnJyMjIwMHDhwAJs3b4aJiQnOnj0Ld3d3vRcp"
                "SElJwcWLF3Hx4kWEh4ernLzKEAgE6N27N0aOHIn+/fvXyDzKz58/R4sWLTB06FBs27YNZmZm"
                "xp4ShUKpAlSAKTqjoKAAR48eRXh4OL766iv4+fkhPj4eP/30EwAgKioK/v7+6Nu3LwBg6NCh"
                "KsHVl5k5LS0Nly5dQnh4OMLDw1UhTOXhcrno3LkzRo4cicGDB8Pa2lovc9EV69evR2FhIf7+"
                "+2/MmzcPDRo0MPaUKBRKFaACTKkyKSkpuHr1KhwcHNCpUycUFBRg5MiRAICgoCBMnToVHTp0"
                "gIeHBzp06ACFQgEAGDhwIAYOHKjz+RQUFODx48d4/PgxHj58iEuXLuHp06eVtnVzc0Pnzp3R"
                "uXNn9OnTB87Ozjqfj77YvHkz4uLiMH78eCq+FEothgowhYioqChcunQJeXl5+OKLLwAAI0aM"
                "wKVLlzB48GB06tQJjo6OaPR/7d15eFTV/cfx92RfJvu+kYSEJJCENSwKEpYoICoqglYqtopK"
                "3duqrf0pYlsVba0W61KliuCCYBGsKJsgoAYRCISEhED2hSxkTyaZ9fz+CFwZgyCCDOL39Tzz"
                "PMyZu5y5QD4595x7TmoqLS0tWK1WAMLCwqioqDirdbHZbBQXF7Nv3z5yc3O1V0lJCUqpE+4T"
                "Hh7OuHHjtND9qQ1Y2rNnD/PmzeOdd95Br9ezcePGH/12vRDixyUBLHopLS1l8eLF7N27lyVL"
                "luDr68u7777L/Pnz0ev1/O53v0On05GWlsaWLVu0pf6gZ3rGwMDAM66DxWKhurqasrIyu9f+"
                "/fvJy8vDYDB8575OTk707duXIUOGaKH7U24plpSUMH78eFpaWpg2bZqErxAXCAngn6Guri66"
                "u7u1Z23vu+8+8vLyePTRR7n88supqanhz3/+MwD79u1j9OjR2nJ+QUFB1NfXExYWxn333ce9"
                "995LUlKSduzvG75Go5Gamhq7cC0vL9f+XFVVpbWiT8bf35+BAwfavdLS0rT5oi8E8fHxXHvt"
                "tSxdupQ77rhDppkU4gIhAXwBy87OJjs7GxcXF+69914Axo4dy7Zt25gzZw6vvfYanp6eLFu2"
                "jI6ODnbt2sXll19OWloaPj4+DBgwAJPJBMCkSZNobm62G6B0/G1cpRTNzc3U1dVRX1+vvb7r"
                "fVtb22l9F71eT2xsLOnp6XZhGxMTcxau1PnHbDazYMECLr30UkaNGsVrr73G3LlzGT58uKOr"
                "JoQ4SySAf4K6u7vZtWsXZWVlTJ06FX9/f1auXMmf/vQnqqqqaG1txdnZmeXLl/P8888TGxur"
                "BfCxAK2oqMBsNtPR0cHEiRMxGo24u7vz2Wef0dHRwauvvkpHRwd79+7liy++oKOj44Sv9vZ2"
                "GhoaaGhowGKx/ODv5O/vT2xsLHFxccTGxtr9OS4ujqCgoLNy7X4qsrKy2Lp1K2+//TY5OTl4"
                "enpK+ApxgZEAdqCamhoqKytxcnLSfrguXLiQoqIihgwZwowZMzCZTIwcOZLGxkYeeOABpk+f"
                "TmFhIddeey0ATzzxBDExMWzbtk3ri/3Nb36DTqdj586d6HQ66uvrGTlyJB0dHTQ0NODt7c3m"
                "zZt7TaW4du3as/r9nJycCAoKIjQ01O4VFhZGaGgo4eHhWtj6+fmd1XP/FJnNZlxcXNDpdNx6"
                "661s3bqVqKgo2tra5FlfIS5Aumm3Pa6Wv/gn3Fx/vlnc2trK119/jdFoxGAwoNPpMJvN1NXV"
                "0draipOTE76+vphMJvLz8+ns7MTf3x9fX1+6urrIycnBaDQSHR2Nl5cXzc3NFBQUYDab6du3"
                "L05OThw+fJiqqipsNhsJCQmYTCZqa2sxGAy4uLjg4eGB2WzWZoI6X7i6uqLX6+1ePj4+du+D"
                "g4N7hWtoaChBQUHn1bSN57N169bxxz/+kblz53LHHXcAPesdX3HFFdLnK8QFxmS2MPOuJyWA"
                "Ab744osLYgk3V1dX3N3dcXNzw8/Pj5CQEPR6PVarVXvv7+9/ykA9vvx8WHDgQtXd3a1NIXnN"
                "NdewatUqfHx8OHDgABEREQ6unRDix3IsgH++qXuc77uEm4uLC1arVXvW1NnZmaioKKqqqlBK"
                "oZTC39+fuLg4iouL6ezsxGazkZSURExMDJWVldrUh1lZWcTGxlJXV8dHH30EwD333ENcXBw5"
                "OTm89dZbACxatAi9Xs97773HBx98QGhoKMuWLcPb25uHHnqILVu2MH78eNauXYubmxuJiYkU"
                "Fxcze/ZsnnvuOWw2m9YKffnll5k7dy55eXkMHz4cX19f1qxZQ0ZGBlu2bGH+/Pl4eXnx5ptv"
                "otfr+fTTT/nqq68IDg7m9ttvB2D37t20tbURERFBcnIy0DOq2t3dXR6N+Z5qamp46qmnWLp0"
                "KXv27CEuLo67776b7Oxs5s+f/5OaFEQI8cNJAAOpqaksXryYvLw8SktLSU9PZ+bMmdTX11NU"
                "VERpaSkxMTHcfvvt1NfXs3v3bkpKSggMDGTWrFkAfPLJJ1RXVxMbG8ull14KwPvvv09HRwfp"
                "6ekMGzYMs9nMkiVLMBqNZGVlkZSURE1NDa+//jpGo5E777yTiIgIsrOz8fX1xWg0Mnv2bFxd"
                "XTEajSilCAkJYfz48QBkZGTQ3t7OwIEDtZZqZ2cngDaH8bHF2gF8fX0BMBgMdHd3093drYVm"
                "aWmp1gf89ttvAz23Rf/2t78RHR2tBfD8+fP53//+x2WXXca6desAGDp0KIWFhdxzzz0sXLgQ"
                "gAkTJuDn58ddd91FVlYWR44c4d133yUgIIApU6YQFBREV1cXXV1d+Pn5XdC3qpuamti6dSvu"
                "7u5MmTIFi8XCyy+/jNVq5ZVXXmHBggVMnDiRyspKXF1dHV1dIcS5Mu22x5XRZFbiwtHZ2ak6"
                "OzuVUkqZzWa1fft2tX79elVTU6OUUqqqqkotWLBAzZs3T9XV1SmllFq7dq2aOnWqGjdunHac"
                "Rx55RAUEBKj09HStbNy4cQpQV199tVYWFRWlAPXII48opZRqa2tTgALUkiVLlFJKZWdna2W7"
                "du1SSim1dOlSBSidTqdaWlqUUkr961//UuPGjVNz5szRjr98+XL18ssvq82bN2tlVVVVqqmp"
                "SZlMprN23c4Gg8Gg8vPz1caNG7WysWPHKkBlZmZqZbNmzVI33XST2rlzpwNqKYRwJKPJrKbd"
                "9riSABanpaqqSu3bt08VFxdrZcuWLVMvvPCC2rFjh1JKqebmZjVjxgyVlZWltm3bppRSasOG"
                "DcrJyUkB2r7PPfecApSTk5Oy2WxKKaXuvPNOBajU1FTt+JmZmb1CPyYmRgHq0UcfVUop1djY"
                "qGJiYlRycrJas2aNUkqp/Px8dc0116jZs2er6upqpZRSOTk5asGCBWrhwoXKarUqpZQqLCxU"
                "W7duVbm5udrxKysrVUFBgaqsrNTKPvnkE7Vy5Up14MABpZRS5eXlas6cOWrKlCmqoKBAKaXU"
                "4sWLFaDc3NyUwWBQSin12GOPKUCFh4dr5xRC/HxJAItzzmq1qoaGBmWxWJRSShUVFal3331X"
                "LVq0SNvmtddeU9ddd526//77tbIRI0YowK5VrNfrFaCeeuoppVRPGB5rYa9evVoppdTGjRu1"
                "sqKiIqWUUgsXLtRa3cfMnTtXAap///5aWUZGhgLUrFmztDIfHx8FqGeeeUYppVRJSUmvc27a"
                "tEkr27Rpk1JKqYqKCpWTkyPhK4RQSn0TwNIHLM4ZJycngoODtff9+vXrtSjCnDlzmDNnjl3Z"
                "V199hclkspvoY8WKFbS2tjJw4ECgZ6ashx9+GIPBoE2NqdfryczMxGAwaM8ZW61WvLy87B7t"
                "OTavtI+Pj1Z2rE/9+MfCvl0WHR1Neno6kZGR6PV6oKc/fMOGDfTt25e+ffsCEBMTc8HO2CWE"
                "+OHkMSTxs2Sz2bQBaHV1dRw5cgQXFxdtZPfOnTvp7OwkPDxcKystLcXZ2ZnAwEAtcIUQ4nTJ"
                "Y0jiZ+34R6bCwsIICwuz+zwjI6PXPvHx8T96vYQQPx/y4KYQQgjhABLAQgghhANIAAshhBAO"
                "IAEshBBCOIAEsBBCCOEAEsBCCCGEA0gACyGEEA4gASyEEEI4gASwEEII4QASwEIIIYQDSAAL"
                "IYQQDiABLIQQQjiABLAQQgjhABLAQgghhANIAAshhBAOIAEshBBCOIAEsBDnubZ2A23tBkdX"
                "w47JbKG+sQWT2eLoqgjxk+Xi6AoIAXCkqY2tO/ZRU9+E3suD1H6xDB+U1Gu74orDfL23iCPN"
                "bUSFBTHh4kH4+Xif8Jg79x2kvLqeKeMy8PJwP+E5t32dR3LfaAb063PS+n22PZfGlvZTfo9r"
                "LrsYo8nMx5993eszZycngvx9SIiLJDI00O6z8up6du47SOaIdIIDfe0+m/fcUoalJXLTtRPt"
                "ygsOVbD/UCUpfaNJTYo9Zd3OpgMlVTz67BLm3z+LwQMSzvrxd+cforSyjmsnXYxOpzvrxxfi"
                "fCABLBxud94hFry8HD9fb1L7xVJcfphV67MZPWwAD95xnbbdhs9zeOXtNfTtE0FESABrt+7i"
                "w43beey+WcRFh2nbGbqMvPruJ3y2PReAsSPSegXwlu37eHXZJ3Qaupk59ZJTBvDOfQcprazV"
                "3jc2t2M0mYkMsw/Sq7JGYejqZunKT/H39cbfV699ZrFYqW9swWyxMjlzGHfceLn2WXH5YZau"
                "/JSUvtF2Adzc1kF5dR23Xj+pV51eW7aW8qp6YiJDeH7eHSet/5na+MUejEYTUyeMAKBPZAi/"
                "v206scdd97Np++5C1m/bzdWXXoSzswSwuDBJAAuHUkrxwuIPiYsO44kHf4WrizMA73/8OW+t"
                "2sTlReWkJsXSaejm9eXrmDh6MHf+8goAurpNPPzMGyx+fwPz7/8lAIZuI/c+/jIRIYFcd/kY"
                "3v/4817nXPz+BjZ+sYc7b7qCv/37/e9Vzwdum273/qmXlrPvQCkv/vmu79znskuGcuO08XZl"
                "JrOFd1ZvZtX6bBJjI5k4evBJz7t3fwlurq6kJMTYlR8sraakopaZUy9h+ZptHCipIrlv9Pf6"
                "Lj/El7v2E3Fcq93Px5tLhqf+aOcT4udAAlg4VKehm3EXDWRIaoIWvgDDByXx1qpNVNQ0kJoU"
                "y+btuXR1m7h20mhtG08PN6aMy+Dlt9ZQebiBmIgQzGYLkzMzmD55NOu27jrhOf18vPnnvDvw"
                "99Of8PMfk5urCzddO5GPN3/N3oKSUwZwzv5iUpNi7a4NwCdbdhLo78PMqWP59Mu9rNu6q1cA"
                "b/g8hz37i3nw9uvsyt9atQmbTTH76C3ttg4Dq9dnU1hchclsJiE2gvTkeEZnDMBmUzz9ynL2"
                "Hyynuq6RI02tzJw6FhcXZ95ZvZkbrswkPiac/IPlfLhhO/fcfBUfbdrB13uLsNps9E+MYdbV"
                "E9B7eZzRdas70sLry9cx6+oJFB6q5NMv99DVbSQ2OoxfXj2BsGB/bdvGlnbe+2gLhcVVuLm4"
                "MKBfH2ZMvQQfb88zqoMQZ5sEsHAovbcnN0/P6lVeVXsEQPvBWlPXSICvnvCQALvt+if20T6P"
                "iQjBz8eb66aMOek5r5l0MQBWm+2M6/9DKaVQSp1im54W8LWTR9uVdxi6+fzrfK7KGoWLizMT"
                "Lx7MqvVfcuvMSXgfF3TlVXV8vbeo13ELDlZisVq1939Z+A6NLe1MzswgMjSQ0spann/9A1xd"
                "nRk+MIkhqYnsyjtEaKAfQ1IT8fXxorahma/2HGDKuAwAmlo6+GrPAZT6EF+9J1ddOorq2iP8"
                "95Mv6Oo2cf8tV5/J5aKr23j0+GCz2ZicmUFbRyfL12yjpq6RZ//vNgBa2jp54InX8NF7MSUz"
                "g9b2TjZs282e/cU88/AcPNxdz6geQpxNEsDivGMyW1ixZhtx0WHaAJ/G5nZ8fbx6bXusZdXY"
                "fOoBUucDq83Gkv9+itliZcSg5JNuW15dR0tbJ4P797Ur35y9F7PForWes8YMZsXHW/lse67W"
                "R/t9NbW0c7CshltmXsZVWaMAGDM8lYTYCLq6Teh0OiZnDuONFevpExXK5MxhANQ2NNsd51gL"
                "3c/Hi7tmX6mVV9Q0kJNffFp1OhFXl54fVe2dBp566NdaeUdnNys+3kZbhwFfvRcfbtxOe2cX"
                "/5w3V/v3ktAngmcX/Zc9+4sZNSTljOsixNkiASzOK52Gbp5+ZQUtbR0s+MMtODn1DMBp7zTg"
                "5dn7NqaHhxvQcxv1fLN5ey75Byu09xaLlZq6RjoM3VyZNZIxw9NOun9OfjGB/j70iQq1K1+3"
                "ZRepSXFan2xokD+D+vdl3dZdpx3Afr7eeHt5sGX7PlISYugXF4VOBxcPG3Baxzlm5LcCLjTI"
                "n+05hVhtNpydzvypx2//0nLsDklTSzu+ei9yC0pJjo+2+2Vt+KAklr3w8BmfW4izTQJYnDdq"
                "G5r56wvvYrFaeeqhX9vdbvbVe1FT39Rrn05DNwABDujPPZUgf1+7ftld+w7SbTTxwvzfEB0R"
                "fMr99+wvYVD/eLuyvANlVNUeYWD/eHbnH9LKYyJC2LO/hIJDlfRPjPn2ob6Ts5MTf5g7g3+9"
                "+T8eeuo/+Pp4MTAlnqzRQxg8oO+pD/Atfnr7uxTOzj2hq2zqrMw64Put4zsdO/7R2/lNre0k"
                "xUed+YmEOAckgMV5obSylnn/WEpcdBh/mDsD/bcGzAQF+FJYXNlrv9b2TgBCAv3OST1Px8CU"
                "OLtR0Jkj0/ndX19lzeYddo8gnYjJbGH/wXLuvvkqu/K1RweWfbz5az7e3PtZ43Vbd50ygG3K"
                "vu97YEo8rzxxD0WlVezZX8L2nELmP/8W0yeP7vXssaOd6plgF2dnLFbH9e0LcTokgIXD1TY0"
                "89jzbzGwfzy/u/VardV0vD6RIaxp66S6tpGo8CCtPL+oHJ1OR0xkyLms8g8SGxXK1ZdexMp1"
                "XzBmeCqp/b578oz8onIsViuDjuv/bW3vJHt3AZePH87tv5jSa5//vLeOdVt3Mef6Sei9PXF2"
                "dsJitaIUHJ9bjc3tve4YODnpSEmIISUhhhuuzORvr77P6o3bmXX1BK0b4KcgKMCHum/1T1ss"
                "VnblHaRPZKjdo1RCOJpMRSkc7qWlHxHk78tvb7nmhOELkDlyIHpvTz5Y94VW1mnoZv223Ywa"
                "knJetoBP5PorMwkLDuBfb/7vpNM45uQXExsVhr/vN7N8bfg8B6vVxmWXDD3hPhNHD8ZktrA5"
                "u2cCkgA/H2w2RXl1nbbNztwi6htbtPe78w9x56Mv2k0yAj23z93dXLUWp6uLMx2dXaf/hb+l"
                "rd3Api/3UnX4yBkf60TGDE+j8nADuYWlWtmmL/fy1EvLKavquQ51Dc1s+nIvjc1tP0odhPi+"
                "pAUsHKrgUAW5haUE+vvwwJOLen1+bApGD3dXbv/FFF5YvJrymgYiQgIoKK7EycmJX149Qdt+"
                "4+c5fLRpBwDtRwPjz/98Rwv2effeyJ8XvmN3jvXbdrPj6OM6V192EeNGDfxRviv0PAc8d9ZU"
                "5j//Fm+v2syvZ1x6wu327C9maFqi9l4pxfqtu+kXF2k369fx4qLDSIyNZN22XVyZNZLRwwbw"
                "9qpNPPGvZVw8rD9tHQbKquoZmppIe2fPoLWUvjE46XTM+8dS0lPiiQwNpL6xhc935nPjVeO1"
                "lnN6Sjxf7Snk2UUryRyZjrvbD3uc53BDEwsXr2bODZO/Vz/46coaPZjtuwt44l/LGDEoiS6j"
                "mb1Hr+WxEdAHSqtZuHg1/3fXDQQF+J7iiEL8eJxTho2fP2PqJd/Z8hDix2SxWPHx9iQhNoLo"
                "iOBer759womJ6Lm9HBsVyohBySilMJstjBycwtwbL7f7IWo0mXF1cSE6IpiEPhGkJcfRJzJE"
                "O17/fn0wdBm192nJcSTGRWrv+8VHEfw9fijrgD5RoQxIPMEUlrqex2bSkuPsJog4JjwkgEA/"
                "H2xK0S8+Svu/F+CnJz05DldXFw6UVHHpJUMJ8vcBoLXdgNVmY9LYYYQG9T7mMRFhgXi6uxEX"
                "HUaAn56LhvbHarPR1mGgT2Qot/9iCj56TyJCg0iMi8TV1YVxF9vGQPMAAA/ASURBVA0kwE9P"
                "V7eR9k4Dgf4+zL52Ipkj07Xj9k/sg6eHG8qmSOkbTVCAL95eHqQlx/X01+t6BkilJcfZTfup"
                "0/V837TkOHQ6HTrgYFkNibERJMRGnPQaR4UHkX5sP50OdzdX0pJj7W6f63Q6/H31pCXH4enu"
                "houzM5mj0gkLCsBgNOLp7sbkzOHcPH2iXf+xv6836clx+Oh7P9omxI/NarOx4uNt6Kbd9rha"
                "/uKfcHOVxrAQ4sf35IvvccXEEQxMiT/1xkJcgExmCzPvelL6gIUQ5057Zxfubi7nfPUmIc5H"
                "0uwVQpwzPt6e/P5bC1sI8XMlLWAhhBDCASSAhRBCCAeQABZCCCEcQAJYCCGEcAAJYCGEEMIB"
                "JICFOIcamlrZ9OXe83L5xG/LLyone3eBo6shxAVLAliIc+hQWQ0LF6+m7kjLqTd2sI83f83i"
                "/250dDWEuGBJAAtxFny8+WuefPG9U26XMTCJN/7+O/rGhJ+DWn1/SiluvPdpu0US7pp9JX97"
                "+FYH1kqIC5sEsBBnwYnWKj5GKWhp68RmU7i6OBPgqz+tudcNXUY6DN1no5p0G03YbKpXeUVN"
                "A4Zuo12Zl6c7vt8xV7JSPcsjWk9z7d1uo/mUt98tFiud3+P7Wq22Xis0KdWz4tLp1ksIR5CZ"
                "sMR567n/fEBtQzNP//EWrWztlp0sWfkps6aNZ+qEEVr5vH8sxcPdjfyD5dw6cxITLh6kffbb"
                "v7zKkaZWXltwPx7uPav4lFTU8sizbzJycDJ79pew6On7cXbqCcU9+0t45t8rGH/RIG67YbJ2"
                "nFfeXsPB0hqefeQ2u3reNe9FDtc3oUPHjfc9zS0zJzE0NYG7H3uJO268nA83bqe4/DB/+9Mc"
                "Wlo7eO71D/jL72eT0OfkixGs3pDNB+u+pKWtE+hZrOHXMy5j7Ig0bZvZv/87ky4Zxqyrx2tl"
                "1bWNPPjUIu785RWMGZ4KwPuffM7/Nn5Fa3snHu6uJMRGcsWEEVw0tD/rtu7ijRXrAXjwqUWE"
                "BPmz8LG5LFy8mtLKOp579HagZ1UpXx8vMtL78dqytbS2d+LkpGPCxYO566Yr7BY7+Lb6xhZe"
                "WvoRewtKUUrh7+vNjdPG2y2teKCkikXL1lJSUYvVZiPAT8+UccO5bsoYbU3iR59dQnhIAHEx"
                "4SxduZFuo5nI0EB+f9t0TGYLz/3nA+obW3B2duIXV43juiljTnqNhXAkCWBx3uqfGMPWHfvo"
                "6OzqWXEH2J1XjLurKzn7S7QA7uo2kV9Uzi3XT6KmvpG9BSVaADc0tVJeXYfe25PC4goGD0gA"
                "YG9BCRaLlUuGp7E5O5fi8sMkxUcBPUsBuru6kpN3yK4+O/cdZOSg5F71fOTuX/D4P98mNMif"
                "22+cQoCvHpPZgqHLyIcbthMbFcrMqZcQHhLAkaZWDF3GE7ZCj5e9u4A3Vmxg5tRLmDJ+ODab"
                "4q0PPuX51z+gT2SItiRhp6Ebk9lst69N2TB0GbFYrQB8sWs/b32wiRuuzGTsiDRcXVzY8HkO"
                "Lyz+kH5xUYzOSKXT0M2SlZ/ywG3TiQrvWSbQaDTbtYqNZjMFxZU0tbQz774b8dN789Gmr1i1"
                "PpthaYlcNLT/Cb+LyWxh/vNv4+rizJMP/gpvLw8++exrXlr6EXovDy4eNoCa+iYefuYNhqX3"
                "46W/3o2Ptydf7trPy2+twWQ2a0tOmswWcg+U0dll5LlH78DQbeTpl1fwwpsf4uXpzm9vvYbg"
                "QF8Wv7+Bt1dtZuyItJOuHiWEI8ktaHHeGpKaiFKQf7ACAJtNkXegjCnjM9h/sFwLsfyD5Vht"
                "NjLSEhmWlkj+wXLtGLkFpfSJDCW1Xyz7Csu+KS8sJT0lnoEp8T0t56Jyu88mj8ugpr6JxpZ2"
                "AA7XN3GkqY1h6f161TMiNBAXF2c83N2IDg/G28sDVxfnng91cO+vpzFycAo+R3+J+D78ffXc"
                "PD2L66/IJMBXT5C/D7OnZ2GzKbvF5r+P8qo6nJ2cmD5lDJFhQYQE+XHjtHE8fNf1uLm5oPfy"
                "IMCvZ9nDsOAAwkMCTngcVxdnjjS18ttbryGhTwTBgb7cOK2n5V1UWv2d59+ZW0RNXSN33Hg5"
                "/RNj6BMZwpzrJ3PR0P40NLUCsGr9l7i5unDfr6YRFuyPl6c7WWOGMGpICms27cBktgDg7OxE"
                "a1snd998JRGhgST0iWDM8FTKquqYdulF9E+MISTQj6uyRqGUoqK6/rSulRDnkgSwOG+FBfsT"
                "FR6khePBsmpMFguTMzMwmsyUVB4GekI2KjyIsJAAhqQmcqSpTRtlnFtYSkpCDP0TY9h3oAzo"
                "6TssOFTBsLREXFycSU+JI+/oOdo7uyitrOXiYf0JC/Yn7+g+uYWluLn2rPF7Ogb173vSz7u6"
                "TXQaurWXxdLTau2fGMM1ky6mpr6RnblFbN2RR05+McBpP8I0MCUem7Lx2HNL+XLXfq3fND05"
                "7jv7eL9LaJC/3Xq8bq4ueLi70n6SOh0sqwEgJSFGK3N2duIPc2cw7dKLACitqKVPZKh2p+OY"
                "lIQYurpNNDS2amXR4cF2aw4f+w6JcZG9ys5W37kQPwa5BS3Oa0NTv2nR5haWkhwfja/ei8TY"
                "SPYVlpEYG0luYSnD0npapqlJsbi7uZJfVE5YsD+5BaXM+cVkwkMCePP9jXR1myitrKXbaNZa"
                "s8PSElmy8lOUUuwrLMXfR09MRAipSbHsO1BG5sh0rcV8uutm6708Tvr5H59+nfLjWmm33TCZ"
                "qRNGUNvQzJMvvUf14SPERofi5emh9VGfrrTkOP4wdyYrPt7GM/9+H50OkvvGcN3lY8g4QYv+"
                "ZI4PvmNO1vcLPYO13N1ctX7cE2loaiUxNrJXub+vNwAt7R1EhQf11MHTvg7Hzn983ZxOUSch"
                "zgcSwOK8NiQtgTWbd2DoNpJbUEp6ShzQ03rbd6CMiaMHU15dx69nXAr03CZNS44jr6iMxLhI"
                "Wto7SE+Ow8fbE3d3VwoOVVBUWk10eDBhwT19g0NSE3nl7Y8pqawlt7CUtKPnSEuKY/marSgF"
                "+wrL+MVV4067/qcKpzk3TMbQ9U0rLS6qp2/3hcUfYujq5t9P3ktwoC/wzSLep2I2W3uVjRqS"
                "wqghKTS3dbB3fwmffLaTv77wLg/feT0jB/fu1z6bvD09MJnNKKW+83r46r1O2FrtPHptfLxP"
                "r6UuxE+B3IIW57W0pDhcnJ3JyS+msLiSgSnxQE9Lt+BQBXv3l+Du5kZqv28WeB+alkh+UTl7"
                "C0qIjQrDV++FTqdjQGIf9h0oY19hGcPSE7Xtw4L9iQwLIu9AOXsLShl09BxpybHUNjSzK+8g"
                "bR0GhqYlcralJ8cxcnCK9goLCUCpntvtGen9tPAFyCsq67W/u6srXd0mu7Lquka79xaLlfaj"
                "t50DfPWMGzWQJx/8FT7enuzKO3jWv9O3hR/9TqWVdXbly9dsZe2WXQBEhAZRU9+I1Wb/+FBl"
                "TQM6nY6QQL8fvZ5CnGsSwOK85ubqQlpSHKvWZ+Ps7ERy32igp4/UZLLw0aYdDOofj8uxQU/A"
                "0NQE6o60sHVHnhbY0HMrdm9BCUWlVb0GUw1NTeDznfkcrm8i/eg+oUH+hAT6sWLNNqIjvmkx"
                "5xaWsvCN1dQcF3Q+3p7UHWlGnXxw8/ei0/X0Zx4srdEGmlXXNrJizee4ujjTdHRgGEBosD97"
                "C0vpNvaMhG5p6+TDDdl2x/vzwnf4/V9fo639m37appZ2uo0mwoIDjta/51Z5bUPTGdf/k892"
                "8sKbH2rvM0em4+HuylsfbMJ8tI97Z24R76z+jJa2DgCmThhOW7uBjz7doe1XXdvI5uxcJl48"
                "CE8PtzOulxDnG7kFLc57Q9IS+M976xiSmqBNYOHh7kZCbAQHSqq485dX2G0fERpIeEgAB0ur"
                "uf6KsVp5alIsi9/fgIe7GwMS+9jtMzQ9kY827SA0yF8L2mP7fLY9VxssBD3BsCl7L1ljhhAZ"
                "1tMvOWJQMm/+dyM3P/B3Jo/N4KqskWf0nS+7ZCj/fGMVtzz0DwL8fGhoauX/7rqe5Wu28dn2"
                "XLqNZh664zpmTL2Efyxaye0P/5OwYH/qG1u59fpJ/GPRSm1A1y0zL+MvC9/h5geeJSo8CE93"
                "N8qq6ugXH8XU8cMBSEvuGQ3+1EvLCfT34cW/3PWD6553oIwvdxdwz81XAaD39uTB26/jH//5"
                "gJt++ww+ei8aGlsZmprI9KPP6Q5MieeXV09gycqNfPrlHjzd3SitrKV/Yh9mX5t1RtdSiPOV"
                "btptj6vlL/7ptAeXCHGudBq6Ka2sJTjQz+4RmaraI7S0dpAQG9mrhVRR00BbeydJfaO1f9s2"
                "m2L/wXI8Pd17TYJhsVgpLK7ER+9FbFSoVt7Q1EpdQzPRESHagKCmlnZq6hrp2yfCbkBQaWUt"
                "NXVNJMZGEBzkR8HBCsJDAu1uI7d1GKiorj9hnb+trKqO0so6PD3cGJgSj5enO91GM3kHSvH0"
                "dNduu9c1NFNUVoOTTkdaciy+em/yi8qIDAsi0L/n8aJjI78bmtpwcXYiPDSQfnH2g54M3Ub2"
                "7i/B08ONQf0TqKptoKvbpD0fXVZVh9VqIyHW/toVHKrAV++tDZKqPNxAW7uB1KRY++N3GSmu"
                "OExTczuRYYH0O3rc4zU2t1FaWUuX0UxUWBDxMeEc321cWlmLTqfTnoM+ts/h+iYG9IvVBnqZ"
                "zBaKSqrs/t6EOF8cG88hASyEEEKcQ8cCWPqAhRBCCAeQABZCCCEcQAJYCCGEcAAJYCGEEMIB"
                "JICFEEIIB5AAFkIIIRxAAlgIIYRwAAlgIYQQwgEkgIUQQggHkAAWQgghHEACWAghhHAACWAh"
                "hBDCASSAhRBCCAeQABZCCCEcQAJYCCGEcAAJYCGEEMIBJICFEEIIB5AAFkIIIRxAAlgIIYRw"
                "AAlgIYQQwgEkgIUQQggHkAAWQgghHEACWAghhHAACWAhhBDCASSAhRBCCAeQABZCCCEcQAJY"
                "CCGEcAAJYCGEEMIBJICFEEIIB5AAFkIIIRxAAlgIIYRwAAlgIYQQwgEkgIUQQggHkAAWQggh"
                "HEACWAghhHAACWAhhBDCASSAhRBCCAeQABZCCCEcQAJYCCGEcAAJYCGEEMIBJICFEEIIB5AA"
                "FkIIIRxAAlgIIYRwAAlgIYQQwgEkgIUQQggHkAAWQgghHEACWAghhHAACWAhhBDCASSAhRBC"
                "CAeQABZCCCEcQAJYCCGEcAAJYCGEEMIBJICFEEIIB5AAFkIIIRxAAlgIIYRwAAlgIYQQwgEk"
                "gIUQQggHkAAWQgghHEACWAghhHAACWAhhBDCASSAhRBCCAeQABZCCCEcQAJYCCGEcAAXAIvF"
                "6uh6CCGEED8LxzJXN+22x5WD6yKEEEL87Pw/SSLp+lk+TSkAAAAASUVORK5CYII=")
        w, h = 480, 258
        bmp = logo.GetBitmap()
        dc = wx.MemoryDC()
        dc.SelectObject(bmp)
        dc.SetFont(wx.FFont(pointSize=9, family=wx.FONTFAMILY_DEFAULT))
        version_text = ' '.join(['Version:', self.version])
        tw, th = dc.GetTextExtent(version_text)
        dc.DrawText(version_text, (w-tw)/2,  (h-th)-10)
        dc.SelectObject(wx.NullBitmap)
        #wx.StaticBitmap(self, -1, bmp)
        return bmp