#!/usr/bin/env python

'''text_display.py - simple wxPython dialog to display text files
Chris R. Coughlin (TRI/Austin, Inc.)
'''

import wx
from wx.lib.wordwrap import wordwrap

class TextDisplay(wx.Frame):
    '''Reads specified text file and displays it to the user'''
    widget_margin = 3.0 # Default border around widgets
    lbl_pct = 0.25 # Default resizing factor for labels - 25%
    ctrl_pct = 1.0 # Default resizing factor for controls - 100%
    sizer_flags = wx.ALL | wx.EXPAND # Default resizing flags for controls

    def __init__(self, textfile, title, parent=None):
        wx.Frame.__init__(self, parent=parent, id=wx.ID_ANY, size=wx.Size(400, 200), title=title)
        self.SetIcon(parent.GetIcon())
        self.fname = textfile
        self.text = unicode(self.read_file())
        self.init_ui()

    def init_ui(self):
        '''Creates the user interface'''
        self.panel =  wx.ScrolledWindow(self, wx.ID_ANY)
        self.panel_sizer = wx.BoxSizer(wx.VERTICAL)
        self.panel.SetScrollbars(1, 1, 1, 1)
        self.text_ctrl = wx.TextCtrl(parent=self.panel, id=wx.ID_ANY, value=self.text, pos=wx.DefaultPosition,
            size=wx.DefaultSize, style=wx.TE_MULTILINE|wx.TE_READONLY)
        self.text_ctrl.SetBackgroundColour(wx.NullColor)
        self.panel_sizer.Add(self.text_ctrl, 1, self.sizer_flags, self.widget_margin)

        self.btn_panel = wx.Panel(self.panel)
        self.btn_panel_sizer = wx.BoxSizer(wx.VERTICAL)
        dismiss_btn = wx.Button(self.btn_panel, wx.ID_ANY, u'Ok', wx.DefaultPosition, wx.DefaultSize)
        dismiss_btn.SetDefault()
        self.Bind(wx.EVT_BUTTON, self.on_close, dismiss_btn)
        self.btn_panel_sizer.Add(dismiss_btn, self.lbl_pct, wx.ALIGN_RIGHT, 5*self.widget_margin)
        self.btn_panel.SetSizerAndFit(self.btn_panel_sizer)
        self.panel_sizer.Add(self.btn_panel, 0, self.sizer_flags, self.widget_margin)
        self.panel.SetSizerAndFit(self.panel_sizer)
        self.SetMinSize(self.panel.GetBestSize())
        
    def read_file(self):
        '''Reads the contents of the text file'''
        with open(self.fname, 'rb') as fidin:
            return ''.join(fidin.readlines())

    def on_close(self, evt):
        '''Closes the display window'''
        self.Destroy()
        